@@ -156,6 +156,7 @@ sub get_default_config_settings
         showrandquote => 1,
         showmuw => 1,
         showmrn => 1,
+        showsmileys => 0,
         showkarma => 0,
         showmru => 1,
         showcharts => 0,
@@ -184,6 +185,7 @@ sub get_default_config_settings
         urlhistory => 5,
         chartshistory => 5,
         nickhistory => 5,
+        smileyhistory => 10,
         karmahistory => 5,
         wordhistory => 10,
         mostnickshistory => 5,
@@ -210,8 +212,10 @@ sub get_default_config_settings
         botnicks => '',            # Needed for DCpp format (non-irc)
 
         statsdump => '',           # Debug option
+        modules_dir => '',         # set in get_cmdline_options
+        cchannels => '',           # set in get_cmdline_options
 
-        version => "0.65",
+        version => "0.66",
     };
 
     # This enables us to use the search_path in other modules
@@ -220,6 +224,10 @@ sub get_default_config_settings
     # Parse the optional overriden configuration variables
     foreach my $key (keys %{$self->{override_cfg}}) {
         if ($self->{override_cfg}->{$key}) {
+            unless (defined($self->{cfg}->{$key})) {
+                print STDERR "Warning: No such configuration option: -cfg $key\n";
+                next;
+            }
             $self->{cfg}->{$key} = $self->{override_cfg}->{$key};
         }
     }
@@ -245,7 +253,8 @@ sub get_language_templates
 
                 # Get 'template = "Text"' in language file:
                 if ($_ =~ /^(\w+)\s*=\s*"(.*)"\s*$/) {
-                    warn "duplicate translation $1 -> $2" if $self->{tmps}->{$current_lang}{$1};
+                    warn "duplicate translation $1 -> $2"
+                        if $self->{tmps}->{$current_lang}{$1} and !$self->{cfg}->{silent};
                     $self->{tmps}->{$current_lang}{$1} = $2;
                 }
             }
