@@ -122,8 +122,15 @@ sub analyze
         monocount  => 0,
         day_lines => [ undef ],
         day_times => [ undef ],
+        parsedlines => 0,
+        totallines => 0,
     );
 
+    if ($self->{cfg}->{cachedir} and not -d $self->{cfg}->{cachedir}) {
+        print STDERR "CacheDir \"$self->{cfg}->{cachedir}\" not found. Skipping caching.\n";
+        delete $self->{cfg}->{cachedir};
+    }
+
     foreach my $logfile (@logfiles) {
         # Run through the logfile
         print "Analyzing log $logfile... " unless ($self->{cfg}->{silent});
@@ -188,10 +195,12 @@ sub _parse_dir
         my @filesarray;
         opendir(LOGDIR, $logdir) or
         die("Can't opendir ${logdir}: $!");
-        @filesarray = grep {
+        unless(@filesarray = grep {
             /^[^\.]/ && /^$self->{cfg}->{logprefix}/ && -f "$logdir/$_"
-        } readdir(LOGDIR) or
-        die("No files in \"$logdir\" matched prefix \"$self->{cfg}->{logprefix}\"");
+            } readdir(LOGDIR)) {
+                print ("No files in \"$logdir\" matched prefix \"$self->{cfg}->{logprefix}\"\n");
+                return;
+        }
         closedir(LOGDIR);
 
         if ($self->{cfg}->{logsuffix} ne '') {
@@ -387,13 +396,21 @@ sub _parse_file
                     }
 
                     # Who smiles the most?
-                    # A regex matching al lot of smilies
-                    $stats->{smiles}{$nick}++
-                        if ($saying =~ /[8;:=][ ^-o]?[)pPD\}\]>]/o);
+                    my $e = '[8;:=%]'; # eyes
+                    my $n = '[-oc*^]'; # nose
+                    # smileys including asian-style (^^ ^_^' ^^; \o/)
+                    if ($saying =~ /(>?$e'?$n[\)pPD\}\]>]|[\(\{\[<]$n'?$e<?|[;:]\)|\([;:]|\^[_o-]*\^[';]|\\[o.]\/)/o) {
+                        $stats->{smiles}{$nick}++;
+                        $stats->{smileys}{$1}++;
+                        $stats->{smileynicks}{$1} = $nick;
+                    }
 
-                    if ($saying =~ /[8;:=][ ^-]?[\(\[\\\/\{]/o and
+                    # asian frown: ;_;
+                    if ($saying =~ /($e'?$n[\(\[\\\/\{|]|[\)\]\\\/\}|]$n'?$e|[;:]\(|\):|;_+;|T_+T|-[._]+-)/o and
                         $saying !~ /\w+:\/\//o) {
                         $stats->{frowns}{$nick}++;
+                        $stats->{smileys}{$1}++;
+                        $stats->{smileynicks}{$1} = $nick;
                     }
 
                     if ($self->{cfg}->{showkarma}) {
@@ -417,7 +434,7 @@ sub _parse_file
                     }
 
                     if ($saying =~ /$self->{chartsregexp}/i) {
-                        $self->_charts($1, $nick);
+                        $self->_charts($stats, $1, $nick);
                     }
 
                     if (my $s = $self->{users}->{sex}{$nick}) {
@@ -483,7 +500,7 @@ sub _parse_file
                 }
 
                 if ($saying =~ /$self->{chartsregexp}/i) {
-                    $self->_charts($1, $nick);
+                    $self->_charts($stats, $1, $nick);
                 }
 
                 $stats->{lengths}{$nick} += length($saying);
@@ -639,7 +656,7 @@ sub _parse_words
 
 sub _charts
 {
-    my ($stats, $Song, $nick) = @_;
+    my ($self, $stats, $Song, $nick) = @_;
     $Song =~ s/_/ /g;
     $Song =~ s/\d+ ?- ?//;
     $Song =~ s/\.mp3//g;
@@ -680,13 +697,19 @@ sub _random_line
 {
     my ($self, $lines, $key, $nick) = @_;
     my $count = 0;
-    my $random;
+    my ($random, $out, $out2) = ("", "", "");
     #warn "$nick did not say anything" unless @{ $lines->{$key}{$nick} };
-    do {
+    while (++$count < 20) {
         $random = ${ $lines->{$key}{$nick} }[rand @{ $lines->{$key}{$nick} }];
-        return '' if ++$count > 20;
-    } while ($self->{cfg}->{noignoredquotes} and $self->{ignorewords_regexp} and $random =~ /$self->{ignorewords_regexp}/i);
-    return $random;
+        if (length($random) < $self->{cfg}->{minquote} or length($random) > $self->{cfg}->{maxquote}) {
+            $out2 = $random; # 2nd best choice
+            next;
+        }
+        next if ($self->{cfg}->{noignoredquotes} and $self->{ignorewords_regexp} and
+                 $random =~ /$self->{ignorewords_regexp}/i);
+        $out = $random;
+    }
+    return $out || $out2;
 }
 
 sub _uniquify_nicks {
@@ -813,7 +836,7 @@ sub _merge_stats
             $stats->{$key} = $s->{$key};
         } elsif ($key =~ /^(parsedlines|totallines)$/) { # {key} = int: add
             $stats->{$key} += $s->{$key};
-        } elsif ($key =~ /^(wordnicks|word_upcase|urlnicks|chartnicks)$/) { # {key}->{} = str: copy
+        } elsif ($key =~ /^(wordnicks|word_upcase|urlnicks|chartnicks|smileynicks)$/) { # {key}->{} = str: copy
             foreach my $subkey (keys %{$s->{$key}}) {
                 $stats->{$key}->{$subkey} = $s->{$key}->{$subkey};
             }
@@ -842,7 +865,7 @@ sub _merge_stats
             }
         } elsif ($key =~ /^topics$/) { # {key}->[] = topic hash: append
             push @{$stats->{$key}}, map {
-                my %a = %$_; $a{days} += $days_offset; \%a; # make new hash
+                my %a = %$_; $a{days} += $days_offset - 1 + $days_rollover; \%a; # make new hash
             } @{$s->{$key}};
         } elsif ($key =~ /^day_lines$/) { # {key}->[] = int: append
             my @list = @{$s->{day_lines}};
